export function useDate() {
  /**
   * @description: 创建一个日期范围
   * @param {*} day 天数
   * @return {*}
   */
  const createDateRange = (day: number): Array<Date> => {
    const end = new Date()
    const start = new Date()
    start.setTime(start.getTime() - 3600 * 1000 * 24 * day)
    return [start, end]
  }

  // 快速选择日期
  const shortcuts: Array<{
    text: string
    value: () => Date[]
  }> = [
    {
      text: '上一周',
      value: () => createDateRange(7),
    },
    {
      text: '上个月',
      value: () => createDateRange(30),
    },
    {
      text: '近三个月',
      value: () => createDateRange(90),
    },
  ]

  /**
   * @description: 禁止选取今天之后的日期
   * @param {*} date
   * @return {*}
   */
  const disableDate = (time: Date) => {
    return time.getTime() > Date.now()
  }

  return {
    shortcuts,
    disableDate,
    createDateRange,
  }
}
