// 总览广告数据类型
interface overviewAdvertisingData {
  name: string
  title: string
  value: number
  rate: number
}

// 选择框类型
enum CSelectType {
  Radio = 'radio',
  MultipleTag = 'multipleTag',
  Multiple = 'multiple',
  RadioLegend = 'radioLegend',
}

// 下拉框选项基础类型
interface CSelectOption {
  label: string
  value: any
}

// 基本下拉框选项类型
interface BaseOption extends CSelectOption {
  value: string
}

// 日期下拉框选项类型
interface DateOption extends CSelectOption {
  value: Date
}

// 总览数据选择框格式
interface CSelectItem {
  name: string
  value: any
  type: CSelectType
  tagText?: string // 展示在多选框的文字，保持不变
  color?: string // 颜色，只在legend中存在
  options: Array<CSelectOption>
}

// 基础选择
interface CSelectRadio extends CSelectItem {
  type: CSelectType.Radio
  options: Array<BaseOption>
  value: string
}

// 日期选择
interface CSelectDate extends CSelectItem {
  type: CSelectType.Radio
  options: Array<DateOption>
  value: Date
}

// 多选带
interface CSelectMutiple extends CSelectItem {
  type: CSelectType.Multiple
  options: Array<BaseOption>
  value: string[]
}

// 带有自定义tag的多选
interface CSelectMutipleTag extends CSelectItem {
  type: CSelectType.MultipleTag
  tagText: string // 展示在多选框的文字，保持不变
  options: Array<BaseOption>
  value: string[]
}

interface CSelectLegend extends CSelectItem {
  type: CSelectType.RadioLegend
  options: Array<BaseOption>
  color: string
  value: string
}

// 选择框信息的基本组织格式
interface CSelectInfo {
  [key: string]: CSelectItem
}

export { CSelectType }

export type {
  overviewAdvertisingData,
  CSelectOption,
  BaseOption,
  DateOption,
  CSelectInfo,
  CSelectItem,
  CSelectRadio,
  CSelectDate,
  CSelectMutiple,
  CSelectMutipleTag,
  CSelectLegend,
}
